@@ -1,8 +1,20 @@
+import logging
+import shlex
 import time
 from functools import wraps
+from pathlib import Path
 
 from hapless import config
 
+logging.disable(level=logging.CRITICAL)
+
+if config.DEBUG:
+    logging.disable(logging.NOTSET)
+    logging.basicConfig(level=logging.DEBUG)
+
+
+logger = logging.getLogger(__package__)
+
 
 def allow_missing(func):
     @wraps(func)
@@ -15,6 +27,11 @@ def allow_missing(func):
     return wrapper
 
 
+def shlex_join_backport(split_command):
+    """Return a shell-escaped string"""
+    return " ".join(shlex.quote(arg) for arg in split_command)
+
+
 class timed(object):
     def __init__(self):
         self._start = time.time()
@@ -33,7 +50,9 @@ class timed(object):
         return self
 
 
-def wait_created(path, interval=0.1, timeout=config.DATETIME_FORMAT):
+def wait_created(
+    path: Path, interval: float = 0.1, timeout: float = config.FAILFAST_DELAY
+):
     start = time.time()
     while not path.exists() and time.time() - start < timeout:
         time.sleep(interval)
